@@ -31,12 +31,12 @@ sub _epoch_to_gmtstring {
     my @months = qw(Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec);
     my @days   = qw(- Mon Tue Wed Thu Fri Sat Sun);
 
-    return
-        $days[$wday] . ", " 
-      . $mday . "-"
-      . $months[$mon] . "-"
-      . ($year + 1900)
-      . " ${hour}:${min}:${sec} GMT";
+    return sprintf "%s, %02d-%s-%d %02d:%02d:%02d GMT",
+        $days[$wday],
+        $mday,
+        $months[$mon],
+        ($year + 1900),
+        $hour, $min, $sec;
 }
 
 1;
