@@ -9,6 +9,7 @@ use Dancer::Cookie;
 use Dancer::Cookies;
 use Dancer::Request;
 use Dancer::Response;
+use Dancer::Serializer;
 use Dancer::Config 'setting';
 use Dancer::FileUtils qw(path dirname read_file_content);
 use Dancer::SharedData;
@@ -78,15 +79,39 @@ sub html_page {
     );
 }
 
-sub get_action_response() {
-    Dancer::Route->run_before_filters;
-    
+sub get_action_response {
     my $request = Dancer::SharedData->request;
     my $path    = $request->path_info;
     my $method  = $request->method;
-
     my $handler = Dancer::Route->find($path, $method, $request);
-    Dancer::Route->call($handler) if $handler;
+
+    # init the request and build the params
+    Dancer::Route->build_params($handler, $request);
+    Dancer::SharedData->request($request);
+
+    # run the before filters
+    Dancer::Route->run_before_filters;
+
+    # recurse if something has changed
+    my $limit = 0;
+    my $MAX_RECURSIVE_LOOP = 10;
+    if (($path ne Dancer::SharedData->request->path) ||
+        ($method ne Dancer::SharedData->request->method)) {
+        $limit++;
+        if ($limit > $MAX_RECURSIVE_LOOP) {
+            die "infinite loop detected, check your route/filters for '$method $path'";
+        }
+        return get_action_response();
+    }
+
+    # execute the action
+    my $response = Dancer::Route->call($handler) if $handler;
+    
+    # serializing the response if needed
+    $response = Dancer::Serializer->process_response($response)
+        if setting('serializer');
+
+    return $response;
 }
 
 sub get_file_response() {
@@ -145,7 +170,7 @@ sub templates {
 <p><% content %></p>
 </div>
 <div id="footer">
-Powered by <a href="http://dancer.sukria.net">Dancer</a> <% version %>
+Powered by <a href="http://perldancer.org/">Dancer</a> <% version %>
 </div>
 </body>
 </html>',
