@@ -1,7 +1,12 @@
-package TestApp;
+package t::lib::TestApp;
 
 use Dancer;
 use Data::Dumper;
+use t::lib::LinkBlocker;
+
+block_links_from "www.foo.com";
+
+get '/' => sub { "Hello, this is the home" };
 
 get '/name/:name' => sub {
     "Your name: ".params->{name}
